"""
Convertible Conversion Transaction Object

Object describing a conversion of a convertible security

Copyright © Shoobx, 2023
Schema is Copyright © 2022 Open Cap Table Coalition (https://opencaptablecoalition.com) /
Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
ree/main/schema/objects/transactions/conversion/ConvertibleConversion.schema.jso
n

Autogenerated, do not edit.
"""

from pyocf.primitives.objects.object import Object
from pyocf.primitives.objects.transactions.conversion.conversion import Conversion
from pyocf.primitives.objects.transactions.securitytransaction import (
    SecurityTransaction,
)
from pyocf.primitives.objects.transactions.transaction import Transaction
from pyocf.types.capitalizationdefinition import CapitalizationDefinition
from pyocf.types.date import Date
from pyocf.types.numeric import Numeric
from typing import Literal


class ConvertibleConversion(Object, Transaction, SecurityTransaction, Conversion):
    """Convertible Conversion Transaction"""

    object_type: Literal["TX_CONVERTIBLE_CONVERSION"] = "TX_CONVERTIBLE_CONVERSION"
    # Reason for the conversion
    reason_text: str
    # Quantity of security units converted
    quantity_converted: Numeric | None
    # Identifier for the convertible that holds the remainder balance (for partial
    # conversions)
    balance_security_id: str | None
    # What is the id of the convertible's conversion trigger that resulted in this
    # conversion
    trigger_id: str
    # If this conversion event was d on the company's capitalization as calculated at
    # the time of conversion, please specify what stock classes, stock plans and
    # securities were included in the calculation
    capitalization_definition: CapitalizationDefinition | None
    # Identifier for the object
    id: str
    # Unstructured text comments related to and stored for the object
    comments: list[str] | None
    # Identifier for the security (stock, plan security, warrant, or convertible) by
    # which it can be referenced by other transaction objects. Note that while this
    # identifier is created with an issuance object, it should be different than the
    # issuance object's `id` field which identifies the issuance transaction object
    # itself. All future transactions on the security (e.g. acceptance, transfer,
    # cancel, etc.) must reference this `security_id` to qualify which security the
    # transaction applies to.
    security_id: str
    # Date on which the transaction occurred
    date: Date
    # Identifier for the security (or securities) that resulted from the conversion
    resulting_security_ids: list[str]
