"""
Plan Security Transfer Transaction Object

Object describing a transfer of a plan security

Copyright © Shoobx, 2023
Schema is Copyright © 2022 Open Cap Table Coalition (https://opencaptablecoalition.com) /
Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
ree/main/schema/objects/transactions/transfer/PlanSecurityTransfer.schema.json

Autogenerated, do not edit.
"""

from pyocf.primitives.objects.object import Object
from pyocf.primitives.objects.transactions.securitytransaction import (
    SecurityTransaction,
)
from pyocf.primitives.objects.transactions.transaction import Transaction
from pyocf.primitives.objects.transactions.transfer.transfer import Transfer
from pyocf.types.date import Date
from pyocf.types.numeric import Numeric
from typing import Literal


class PlanSecurityTransfer(Object, Transaction, SecurityTransaction, Transfer):
    """Plan Security Transfer Transaction"""

    object_type: Literal["TX_PLAN_SECURITY_TRANSFER"] = "TX_PLAN_SECURITY_TRANSFER"
    # Quantity of non-monetary security units transferred
    quantity: Numeric
    # Identifier for the object
    id: str
    # Unstructured text comments related to and stored for the object
    comments: list[str] | None
    # Identifier for the security (stock, plan security, warrant, or convertible) by
    # which it can be referenced by other transaction objects. Note that while this
    # identifier is created with an issuance object, it should be different than the
    # issuance object's `id` field which identifies the issuance transaction object
    # itself. All future transactions on the security (e.g. acceptance, transfer,
    # cancel, etc.) must reference this `security_id` to qualify which security the
    # transaction applies to.
    security_id: str
    # Date on which the transaction occurred
    date: Date
    # Unstructured text description of consideration provided in exchange for security
    # transfer
    consideration_text: str | None
    # Identifier for the security that holds the remainder balance (for partial
    # transfers)
    balance_security_id: str | None
    # Array of identifiers for new security (or securities) created as a result of the
    # transaction
    resulting_security_ids: list[str]
